// start OSC config
import oscP5.*;
import netP5.*;
  
/*portToListenTo, port we are listening on, this should be the same as
the outgoing port of TouchOsc on your iphone
*/
int portToListenTo = 7001; 

/*portToSendTo, port we are sending to, this should be the same as
the incomning port of Resolume 3, default it is set to 7000, so you wouldn't need to change it.
*/
int portToSendTo = 7000;

/*ipAddressToSendTo, ip address of the computer we are sending messages to (where Resolume 3 runs)
*/
String ipAddressToSendTo = "localhost";

OscP5 oscP5;
NetAddress myRemoteLocation;
OscBundle myBundle;
OscMessage myMessage;
//end OSC config

PFont font;

int column = 0;
//int curColumn = 1;

void setup()
{
  size(640,480);
  frameRate(25);
  smooth();
  strokeWeight(2);
  
  //setup OSC communication
  oscP5 = new OscP5(this,portToListenTo);
  myRemoteLocation = new NetAddress(ipAddressToSendTo, portToSendTo);  
  myBundle = new OscBundle();
  myMessage = new OscMessage("/"); 
  
  font = loadFont("Arial-Black-24.vlw"); 
  textFont(font, 18); 
}


void draw() {
  //limit column to max numbers
  column = constrain(column, 0, 99);
  
  background(32);
  
  fill(255,0,0);
  stroke(255);
  
  //draw buttons
  ellipse(width/2+25, height/2, 150,150); 
  ellipse(width/2-100, height/2, 50,50);

  //if we lose focus, draw darker
  if(!focused)
  {
    fill(0,200);
    noStroke();
    rect(0,0,width,height);
  }
}


void mouseReleased()
{
  float disX;
  float disY;
  
  //if we're over the center button
  disX = width/2 + 25 - mouseX;
  disY = height/2 - mouseY;
  if(sqrt(sq(disX) + sq(disY)) < 75 )
  {
    column++;
    send();   
  }
  
  //if we're over the left  button
  disX = width/2 - 100 - mouseX;
  disY = height/2 - mouseY;
  if(sqrt(sq(disX) + sq(disY)) < 25 )
  {
    column--;
    send();
  }
}

void keyPressed() 
{
  switch(key)
  {
    case ']': 
      send();
      column++;
      break;
    case '[':
      send(); 
      column--;
      break;
  } 
}

void send() 
{   
  String address = ("/track"+column+"/connect/");
  myMessage.setAddrPattern(address);
  myMessage.add(1);
  myBundle.add(myMessage);
  myMessage.clear();
  oscP5.send(myBundle, myRemoteLocation); 
 
  myBundle.clear();
  
  if(column == 0)
  {
    address = ("/composition/disconnectall");
    myMessage.setAddrPattern(address);
    myMessage.add(1);
    myBundle.add(myMessage);
    myMessage.clear();
    oscP5.send(myBundle, myRemoteLocation); 
 
    myBundle.clear();
  }
}

void oscEvent(OscMessage theOscMessage) 
{
  for (int i = 1; i < 100; i++)
  {
    if(theOscMessage.addrPattern().equals("/track"+i+"/select") || theOscMessage.addrPattern().equals("/track"+i+"/select"))
    {
      column = i;
    }
  }
  
  if(theOscMessage.addrPattern().equals("/composition/disconnectall"))
    column = 0;
}

